bottomPosition property
The position from the bottom of the screen where the button and the text form will be placed
Implementation
final double bottomPosition;
The position from the bottom of the screen where the button and the text form will be placed
final double bottomPosition;