onLockedRecording property
Callback when the recording is locked, providing a boolean indicating if it was locked successfully
Implementation
final Function(bool doesLocked)? onLockedRecording;
Callback when the recording is locked, providing a boolean indicating if it was locked successfully
final Function(bool doesLocked)? onLockedRecording;