onRecordingEnd property
Callback when recording ends, providing the file path of the recording
Implementation
final Function(File? filePath) onRecordingEnd;
Callback when recording ends, providing the file path of the recording
final Function(File? filePath) onRecordingEnd;