onSend property
Callback when the send button is pressed, providing the text from the input field
Implementation
final Function(String text) onSend;
Callback when the send button is pressed, providing the text from the input field
final Function(String text) onSend;