onStartRecording property
Callback when the recording starts, providing a boolean indicating if it started successfully
Implementation
final Function(bool doesStartRecording)? onStartRecording;
Callback when the recording starts, providing a boolean indicating if it started successfully
final Function(bool doesStartRecording)? onStartRecording;