recordingOutputPath property
the path where the recording will be saved ex : /storage/emulated/0/Android/data/com.example.animated_chat_record_button_example/files/recording_1753372209083.aac
Implementation
final String? recordingOutputPath;
the path where the recording will be saved ex : /storage/emulated/0/Android/data/com.example.animated_chat_record_button_example/files/recording_1753372209083.aac
final String? recordingOutputPath;