RecordButtonState class

State management for record button animations

Constructors

RecordButtonState({required bool isReachedCancel, required bool isReachedLock, required bool isMoving, required bool isMovingVertical, required bool isHorizontalMoving, required double roundedOpacity, required double roundedContainerHorizontal, required double onHorizontalButtonScale, required double verticalScale, required double roundedContainerVal, required double xAxisVal, required double dyOffsetVerticalUpdate})
const

Properties

dyOffsetVerticalUpdate double
final
hashCode int
The hash code for this object.
no setterinherited
isHorizontalMoving bool
final
isMoving bool
final
isMovingVertical bool
final
isReachedCancel bool
final
isReachedLock bool
final
onHorizontalButtonScale double
final
roundedContainerHorizontal double
final
roundedContainerVal double
final
roundedOpacity double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verticalScale double
final
xAxisVal double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited