AnimationGlop class

Inheritance
Mixed-in types

Constructors

AnimationGlop(BuildContext context)

Properties

amplitudesController ↔ List<double>
getter/setter pair
arrowOpacity ↔ ValueNotifier<double>
getter/setter pair
audioHandlers ↔ AudioHandlers
getter/setter pair
colorAnimation ↔ Animation<Color?>
getter/setter pair
colorController ↔ AnimationController
getter/setter pair
context → BuildContext
The location in the tree where this widget builds.
final
currentDirection ↔ String
getter/setter pair
dyOffsetVerticalUpdate ↔ ValueNotifier<double>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initialOffset ↔ Offset
getter/setter pair
isHorizontalMoving ↔ ValueNotifier<bool>
getter/setter pair
isMoving ↔ ValueNotifier<bool>
getter/setter pair
isMovingVertical ↔ ValueNotifier<bool>
getter/setter pair
isReachedCancel ↔ ValueNotifier<bool>
getter/setter pair
isReachedLock ↔ ValueNotifier<bool>
getter/setter pair
lockValue ↔ double
getter/setter pair
micFadeAnimation ↔ Animation<double>
getter/setter pair
micFadeController ↔ AnimationController
getter/setter pair
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
onHorizontalButtonScale ↔ ValueNotifier<double>
getter/setter pair
recordButtonScale ↔ double
getter/setter pair
recordButtonSize ↔ double
getter/setter pair
recordTimer ↔ Timer?
getter/setter pair
reverseAnimation → VoidCallback
no setter
roundedContainerHight ↔ double
getter/setter pair
roundedContainerHorizontal ↔ ValueNotifier<double>
getter/setter pair
roundedContainerVal ↔ ValueNotifier<double>
getter/setter pair
roundedContainerWidth ↔ double
getter/setter pair
roundedOpacity ↔ ValueNotifier<double>
getter/setter pair
roundedVerticalContainerAnimation → Animation<double>
no setter
roundedVerticalContainerAnimationHight → Animation<double>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleAnimation → Animation<double>
no setter
secondsElapsed ↔ ValueNotifier<int>
getter/setter pair
shackleAnimation ↔ Animation<double>
getter/setter pair
shackleAnimationController ↔ AnimationController
getter/setter pair
shackleLock ↔ ValueNotifier<double>
getter/setter pair
shouldStartVisualizer ↔ ValueNotifier<bool>
getter/setter pair
slideUpArrowAnimation → Animation<double>
no setter
startAnimation → VoidCallback
no setter
verticalScale ↔ ValueNotifier<double>
getter/setter pair
vipration ↔ Vibration?
getter/setter pair
widget → StatefulWidget
The current configuration.
no setterinherited
xAxisVal → ValueNotifier<double>
final

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createTicker(TickerCallback onTick) → Ticker
Creates a ticker with the given callback.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant StatefulWidget oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
initialize({double roundedContainerHightt = 170, required double recordButtonSizeInit, double recordButtonScaleInit = 1.9, double roundedContainerWidhdInit = 55, required Color lockColorFirst, required Color lockColorSecond}) → void
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onHorizontalCancel() → void
onHorizontalEnd(dynamic details) → void
onHorizontalUpdate(dynamic details) → void
onPanCancel() → void
onPanEnd(dynamic details) → void
onPanUpdate(dynamic details) → void
onVerticalDragCancel() → dynamic
onVerticalDragEnd(dynamic details) → void
onVerticalDragUpdate(dynamic details) → void
pauseTimer() → void
playTimer() → void
preWarm() → void
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
startColorAnimation() → void
startMicFade() → void
startShackleAnimation() → void
startSlideUpIconAnimaiton() → void
startTimerRecord() → void
stopColorAnimation() → void
stopMicFade() → void
stopShackleAnimation() → void
stopSlideUpIconAnimation() → void
stopTimer() → void
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toggleLock() → void
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited