CustomTextForm class

Inheritance

Constructors

CustomTextForm({Key? key, double border = 20, Color boxFillColor = const Color.fromARGB(255, 217, 214, 214), String hinText = 'Email', bool isPasss = false, TextEditingController? controller, String? validate(String? val)?, TextInputType? keyBoardType, bool autoFocus = false, bool cursorOpacityAanimation = true, double cursorHight = 30, double cursorWidth = 2, double cursorRadius = 20, Color cursorColor = Colors.grey, InputDecoration? inputDecoration, Widget? suffixIcon, Widget? preffixIcon, EdgeInsets? contentPading, TextStyle? hintStyle, FocusNode? focusNode, TextStyle? enteredTextStyle, dynamic onChanged(String)?, dynamic onSupmit(String)?})
const

Properties

autoFocus bool
final
border double
final
boxFillColor Color
final
contentPading EdgeInsets?
final
controller TextEditingController?
final
cursorColor Color
final
cursorHight double
final
cursorOpacityAanimation bool
final
cursorRadius double
final
cursorWidth double
final
enteredTextStyle TextStyle?
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
hinText String
final
hintStyle TextStyle?
final
inputDecoration InputDecoration?
final
isPasss bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyBoardType TextInputType?
final
onChanged → dynamic Function(String)?
final
onSupmit → dynamic Function(String)?
final
preffixIcon Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffixIcon Widget?
final
validate String? Function(String? val)?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CustomTextForm>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited