AnimatedChatRecordButton class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- AnimatedChatRecordButton
Constructors
- AnimatedChatRecordButton({Key? key, RecordButtonConfig config = const RecordButtonConfig(), TextEditingController? textEditingController, String? recordingOutputPath, required dynamic onRecordingEnd(File? filePath), required dynamic onSend(String text), RecordingContainerConfig? recordingContainerConfig, dynamic onStartRecording(bool doesStartRecording)?, dynamic onLockedRecording(bool doesStartRecording)?, double bottomPosition = 5, VoidCallback? onPressCamera, VoidCallback? onPressAttachment, VoidCallback? onPressEmoji, Color? textFormButtonsColor = const Color.fromARGB(255, 116, 116, 116), Color arrowColor = Colors.grey, Color lockColorFirst = Colors.grey, Color lockColorSecond = Colors.black})
-
Creates an instance of AnimatedChatRecordButton
const
Properties
- arrowColor → Color
-
Optional colors for the arrow
final
- bottomPosition → double
-
The position from the bottom of the screen where the button and the text form will be placed
final
- config → RecordButtonConfig
-
Configuration for the record button , text field, and slide-up container
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lockColorFirst → Color
-
Optional colors for the lock icons animation
final
- lockColorSecond → Color
-
final
- onLockedRecording → dynamic Function(bool doesStartRecording)?
-
Callback when the recording is locked, providing a boolean indicating if it was locked successfully
final
- onPressAttachment → VoidCallback?
-
Callbacks for attachment button presses
final
- onPressCamera → VoidCallback?
-
Callbacks for camera button presses
final
- onPressEmoji → VoidCallback?
-
Callbacks for emoji button presses
final
- onRecordingEnd → dynamic Function(File? filePath)
-
Callback when recording ends, providing the file path of the recording
final
- onSend → dynamic Function(String text)
-
Callback when the send button is pressed, providing the text from the input field
final
- onStartRecording → dynamic Function(bool doesStartRecording)?
-
Callback when the recording starts, providing a boolean indicating if it started successfully
final
- recordingContainerConfig → RecordingContainerConfig?
-
Configuration for the recording container , waveforms , and icons
final
- recordingOutputPath → String?
-
the path where the recording will be saved ex : /storage/emulated/0/Android/data/com.example.animated_chat_record_button_example/files/recording_1753372209083.aac
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textEditingController → TextEditingController?
-
TextEditingController to manage the text input field
final
- textFormButtonsColor → Color?
-
Color for the text form buttons
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< AnimatedChatRecordButton> -
Creates an instance of AnimatedChatRecordButton with a recording output path
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited