RecordButtonConfig class
Configuration class for styling the record button
Constructors
- RecordButtonConfig({double? slideUpContainerHeight, Color? slideUpContainerColor, Color? firstRecordButtonColor, Color? secondRecordButtonColor, Color? textFormFieldBoxFillColor, String? textFormFieldHint, TextStyle? textFormFieldStyle, TextStyle? textFormFieldHintStyle, EdgeInsetsGeometry containersPadding = const EdgeInsets.only(left: 8), Icon firstRecordingButtonIcon = const Icon(Icons.mic, color: Colors.white), Icon secondRecordingButtonIcon = const Icon(Icons.send_rounded, color: Colors.white), double recordButtonSize = 40, double recordButtonScaleVal = 2.5, double slideUpContainerWidth = 50})
-
const
Properties
- containersPadding → EdgeInsetsGeometry
-
final
- firstRecordButtonColor → Color?
-
final
- firstRecordingButtonIcon → Icon
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- recordButtonScaleVal → double
-
final
- recordButtonSize → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondRecordButtonColor → Color?
-
final
- secondRecordingButtonIcon → Icon
-
final
- slideUpContainerColor → Color?
-
final
- slideUpContainerHeight → double?
-
final
- slideUpContainerWidth → double
-
final
- textFormFieldBoxFillColor → Color?
-
final
- textFormFieldHint → String?
-
final
- textFormFieldHintStyle → TextStyle?
-
final
- textFormFieldStyle → TextStyle?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited